Poolder.PubSub.Monitor (Poolder v0.1.16)

Lightweight monitor process (not a GenServer) that:

  • Creates monitors for subscribed pids
  • Demonitor pids that no longer have subscriptions
  • Cleans up subscriptions upon receiving :DOWN

Summary

Functions

Starts the monitor process linked to the given ETS.

Functions

start_link(table)

Starts the monitor process linked to the given ETS.