Poolder.PubSub (Poolder v0.1.16)
View SourceETS-based public PubSub, identified by a logical server.
serveris the name you pass to start_link/1- Internally, the ETS table is registered in :persistent_term with key {:pubsub, server}
- All functions receive the server as the first argument and resolve the ETS from there
Summary
Functions
Starts a PubSub server named server and creates the public ETS.
Types
Functions
Starts a PubSub server named server and creates the public ETS.
Options:
- :table => ETS name (by default uses :"#{server}_pubsub")